@@ -81,14 +81,5 @@ class CustomerView(base.CustomerView):
 
 
 def includeme(config):
-
-    # autocomplete
-    # TODO: ugh
-    config.add_route('customers.autocomplete', '/customers/autocomplete')
-    config.add_view(base.CustomerNameAutocomplete, route_name='customers.autocomplete',
-                    renderer='json', permission='customers.list')
-    config.add_route('customers.autocomplete.phone', '/customers/autocomplete/phone')
-    config.add_view(base.CustomerPhoneAutocomplete, route_name='customers.autocomplete.phone',
-                    renderer='json', permission='customers.list')
-
     CustomerView.defaults(config)
+    base.PendingCustomerView.defaults(config)
